"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.listHandler = void 0;
const workspace_root_1 = require("../../utils/workspace-root");
const output_1 = require("../../utils/output");
const plugins_1 = require("../../utils/plugins");
const local_plugins_1 = require("../../utils/plugins/local-plugins");
const project_graph_1 = require("../../project-graph/project-graph");
const nx_json_1 = require("../../config/nx-json");
/**
 * List available plugins or capabilities within a specific plugin
 *
 * @remarks
 *
 * Must be run within an Nx workspace
 *
 */
async function listHandler(args) {
    if (args.plugin) {
        await (0, plugins_1.listPluginCapabilities)(args.plugin);
    }
    else {
        const nxJson = (0, nx_json_1.readNxJson)();
        const corePlugins = (0, plugins_1.fetchCorePlugins)();
        const projectGraph = await (0, project_graph_1.createProjectGraphAsync)({ exitOnError: true });
        const localPlugins = await (0, local_plugins_1.getLocalWorkspacePlugins)((0, project_graph_1.readProjectsConfigurationFromProjectGraph)(projectGraph), nxJson);
        const installedPlugins = await (0, plugins_1.getInstalledPluginsAndCapabilities)(workspace_root_1.workspaceRoot);
        if (localPlugins.size) {
            (0, local_plugins_1.listLocalWorkspacePlugins)(localPlugins);
        }
        (0, plugins_1.listInstalledPlugins)(installedPlugins);
        (0, plugins_1.listCorePlugins)(installedPlugins, corePlugins);
        output_1.output.note({
            title: 'Community Plugins',
            bodyLines: [
                'Looking for a technology / framework not listed above?',
                'There are many excellent plugins maintained by the Nx community.',
                'Search for the one you need here: https://nx.dev/plugins/registry.',
            ],
        });
        output_1.output.note({
            title: `Use "nx list [plugin]" to find out more`,
        });
    }
}
exports.listHandler = listHandler;
