"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.handleHashTasks = void 0;
const project_graph_incremental_recomputation_1 = require("./project-graph-incremental-recomputation");
const task_hasher_1 = require("../../hasher/task-hasher");
const configuration_1 = require("../../config/configuration");
const set_hash_env_1 = require("../../hasher/set-hash-env");
/**
 * We use this not to recreated hasher for every hash operation
 * TaskHasher has a cache inside, so keeping it around results in faster performance
 */
let storedProjectGraph = null;
let storedHasher = null;
async function handleHashTasks(payload) {
    (0, set_hash_env_1.setHashEnv)(payload.env);
    const { projectGraph, allWorkspaceFiles, fileMap } = await (0, project_graph_incremental_recomputation_1.getCachedSerializedProjectGraphPromise)();
    const nxJson = (0, configuration_1.readNxJson)();
    if (projectGraph !== storedProjectGraph) {
        storedProjectGraph = projectGraph;
        storedHasher = new task_hasher_1.InProcessTaskHasher(fileMap?.projectFileMap, allWorkspaceFiles, projectGraph, nxJson, payload.runnerOptions);
    }
    const response = JSON.stringify(await storedHasher.hashTasks(payload.tasks, payload.taskGraph));
    return {
        response,
        description: 'handleHashTasks',
    };
}
exports.handleHashTasks = handleHashTasks;
